@@ -1,4 +1,8 @@
+use strict;
+use warnings;
 package Rubric::CLI;
+use base qw(App::Cmd);
+our $VERSION = '0.143';
 
 =head1 NAME
 
@@ -6,13 +10,8 @@ Rubric::CLI - the Rubric command line interface
 
 =head1 VERSION
 
- $Id: /my/cs/projects/rubric/trunk/lib/Rubric/CLI.pm 1425 2006-08-14T17:02:44.651525Z rjbs  $
+version 0.143
 
 =cut
 
-use strict;
-use warnings;
-
-use base qw(App::Cmd);
-
 1;
