@@ -1,5 +1,8 @@
+use strict;
+use warnings;
 package Rubric::CLI::Command::db;
 use base qw(Rubric::CLI::Command);
+our $VERSION = '0.143';
 
 =head1 NAME
 
@@ -7,13 +10,10 @@ Rubric::CLI::Command::db - database management
 
 =head1 VERSION
 
- $Id: /my/cs/projects/rubric/trunk/lib/Rubric/CLI/Command/db.pm 1425 2006-08-14T17:02:44.651525Z rjbs  $
+version 0.143
 
 =cut
 
-use strict;
-use warnings;
-
 use Rubric::DBI::Setup;
 
 sub usage_desc { "rubric database %o" }
