@@ -1,3 +1,5 @@
+use strict;
+use warnings;
 package Rubric::WebApp::Entries;
 
 =head1 NAME
@@ -6,13 +8,11 @@ Rubric::WebApp::Entries - process the /entries run method
 
 =head1 VERSION
 
-version 0.10
-
- $Id: /my/cs/projects/rubric/trunk/lib/Rubric/WebApp/Entries.pm 1425 2006-08-14T17:02:44.651525Z rjbs  $
+version 0.143
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.143';
 
 =head1 DESCRIPTION
 
@@ -25,9 +25,6 @@ on the results.
 use Date::Span;
 use Digest::MD5 qw(md5_hex);
 
-use strict;
-use warnings;
-
 use Rubric::Config;
 use Rubric::Entry;
 use Rubric::Renderer;
@@ -124,7 +121,7 @@ value of C<$param>.  If no clause can be generated, it returns undef.
 sub get_arg {
 	my ($self, $param, $value) = @_;
 
-	return undef unless my $code = $self->can("arg_for_$param");
+	return unless my $code = $self->can("arg_for_$param");
 	$code->($self, $value);
 }
 
@@ -142,8 +139,8 @@ Given a username, this method returns the associated Rubric::User object.
 
 sub arg_for_user {
 	my ($self, $user) = @_;
-	return undef unless $user;
-	return Rubric::User->retrieve($user) || undef;
+	return unless $user;
+	return Rubric::User->retrieve($user) || ();
 }
 
 =head3 arg_for_tags($tagstring)
@@ -233,7 +230,7 @@ md5sum.
 
 sub arg_for_urimd5 {
 	my ($self, $md5) = @_;
-	return undef unless $md5 =~ /\A[a-z0-9]{32}\Z/i;
+	return unless $md5 =~ /\A[a-z0-9]{32}\Z/i;
 	return $md5;
 }
 
@@ -247,6 +244,7 @@ They return the passed string unchanged.
 
 ## more date-arg handling code
 {
+  ## no critic (ProhibitNoStrict)
 	no strict 'refs';
 	for my $field (qw(created modified)) {
 		for my $prep (qw(after before on)) {
